import { defineComponent } from 'vue'
import styles from './index.module.less'
import iconTeacher from '@/common/images/icon_teacher.png'
import {
  ElButton,
  ElImage,
  ElMessage,
  ElMessageBox,
  ElRate,
  ElTag
} from 'element-plus'
// import iconVip from '../images/icon_vip.png'
import iconVip from '../../user-info/images/icon_vip.png'
import request from '@/helpers/request'

export default defineComponent({
  name: 'item',
  props: {
    item: {
      type: Object,
      default: {}
    },
    getList: {
      type: Function,
      default: () => {}
    }
  },
  computed: {
    subjects() {
      const { subjectName } = this.item
      return subjectName.split(',')
    }
  },
  methods: {
    async onUnLike() {
      // console.log(this.item)
      ElMessageBox.confirm('确定取消关注吗？', '提示').then(async () => {
        try {
          await request.get('/api-website/student/starOrUnStar', {
            params: {
              userId: this.item.userId,
              starStatus: 0
            }
          })
          ElMessage.success('取消关注成功')
          this.getList()
        } catch {
          //
        }
      })
    }
  },
  render() {
    const item = this.item
    return (
      <div class="w-[158px] rounded-[10px] pt-10  mb-4 m-auto user-shadow relative">
        <div class="bg-[#CFF2FF] absolute left-2.5 top-2.5 text-[#0089B9] text-xs py-0.5 px-2 rounded-[10px]">
          老师
        </div>
        <div class="flex flex-col items-center">
          <ElImage
            src={item.avatar || iconTeacher}
            class="w-12 h-12 rounded-full border-2 border-[#2DC7AA] object-cover"
          />
          {item.isVip > 0 && <ElImage src={iconVip} class="h-7 -mt-4" />}
        </div>

        <p class="text-base text-[#333] font-semibold leading-tight pb-5 pt-2 text-center">
          {item.userName}
        </p>
        <p class="mx-4 text-center mb-3">
          {this.subjects.map(subject => (
            <ElTag
              effect="dark"
              size="small"
              color="#E0FEF9"
              round
              style={{
                borderColor: '#E0FEF9',
                color: '#1B967E',
                margin: '0 4px 8px'
              }}
            >
              {subject}
            </ElTag>
          ))}
        </p>

        <div class="border-[#E7E6E6] border-t block mx-2.5 pt-1 pb-2 text-center">
          <ElButton
            type="text"
            plain
            size="small"
            class="!bg-white !text-[#999999] hover:!text-[#FF8B00]"
            onClick={this.onUnLike}
          >
            取消关注
          </ElButton>
        </div>
      </div>
    )
  }
})
